# importing modules
import sys as sys
import os 
import pandas as pd 
import matplotlib.pyplot as plt
# Getting the name of the directory where this file is present.
current = os.path.dirname(os.path.realpath(__file__))  # src
# Getting the parent directory name where the current directory is present.
parent = os.path.dirname(current) # Simulation
# Getting the grandparent directory name
gparent = os.path.dirname(parent) # RecruitmentSynchronization_SMCs
# The path where the plotExp.py is saved
mpath = gparent + '\\cellLib\\Scripts'
# appending a path
sys.path.append(mpath)
import plotExp
# The properties of traces
colors=plt.rcParams['axes.prop_cycle'].by_key()['color']
lines = ['-','--','-.',':']
markers = ['.',',','o','+','x','d']
# Figure file name and titles
figfiles=parent+'\\simFig14.png'
fig_title = 'Primary Fig 14'
plot_title =['Reference -40mV','Perchlorate -40mV','Reference -20mV','Perchlorate -20mV',]
labels = ['Original','CellML']
# Data source
dfolder_original=parent+'\\originalData\\'
ofilenames=['Fig14_n40r.csv','Fig14_n40p.csv','Fig14_n20r.csv','Fig14_n20p.csv']
dfilenames=['simFig14_r_0.csv','simFig14_p_0.csv','simFig14_r_1.csv','simFig14_p_1.csv']
dfolder_sim=parent+'\\simulatedData\\'
x_var_org ='x'
y_var_org ='Curve1'
x_vars_sim = ['t','t','t','t']
y_vars_sim = ['output_18/dQ','output_18/dQ','output_18/dQ','output_18/dQ']
x_label=['t (ms)','t (ms)','t (ms)','t (ms)']
y_label=['Charge current /ms','Charge current /ms','Charge current /ms','Charge current /ms']
Qmax=23.1
# Build the traces
number_trace = 2
number_plot = len(y_vars_sim)
trace = [[0] * number_trace for i in range(number_plot)]


for plotid, y_var_sim in enumerate(y_vars_sim):
   odata = pd.read_csv(dfolder_original+ofilenames[plotid])
   ox_data=odata[x_var_org].values
   oy_data=odata[y_var_org].values 
   ndata = pd.read_csv(dfolder_sim+dfilenames[plotid])
   nx_data=ndata[x_vars_sim[plotid]].values-210
   ny_data=ndata[y_vars_sim[plotid]].values    
   trace[plotid][0]={'dataX': ox_data, 'dataY': oy_data, 'lname': labels[0], 'linestyle':lines[1], 'marker':markers[0], 'linecolor':colors[0],'y2':False}
   trace[plotid][1]={'dataX': nx_data, 'dataY': ny_data, 'lname': labels[1], 'linestyle':lines[0], 'marker':None, 'linecolor':colors[1],'y2':False}
   
        
# Build the plots 
# maxH=8.75 inches, width 2.63-7.5
rows,cols = 2,2
left = 0.15  # the left side of the subplots of the figure,0.125
right = 0.95   # the right side of the subplots of the figure,0.9
bottom = 0.1  # the bottom of the subplots of the figure, 0.1
top = 0.85     # the top of the subplots of the figure 0.9
wspace = 0.5  # the amount of width reserved for space between subplots,
              # expressed as a fraction of the average axis width, 0.2
hspace = 0.5  # the amount of height reserved for space between subplots,
              # expressed as a fraction of the average axis height, 0.2
lgdfont, labelfont =10, 10
width, height= cols*3, rows*2.5
figs ={ 'width':width, 'height': height, 'rows': rows, 'cols': cols,'left':left,'bottom':bottom,'right':right,'top':top,'wspace': wspace,'hspace': hspace,'fig_title':fig_title,'title_y':1}

plots=[]
for id in range(4):    
   colid = id%2
   rowid = id//2
   if id == 0:
      lgdshow = True
      bbox_to_anchor = (1.2,1.25)      
   else:
      lgdshow = False
      bbox_to_anchor = None
       
   iplot={'rowid':rowid, 'colid':colid, 'xlabel': x_label[id], 'ylabel':y_label[id], 'twiny':False,    'ylabel2':y_label[id],'labelcolor':colors[1],
            'lgdshow': lgdshow, 'lgdloc':'center', 'bbox_to_anchor':bbox_to_anchor,'lgdncol': 2, 'lgdfont':lgdfont, 'labelfont': labelfont,  
            'setxlim': True, 'xmin':-10, 'xmax': 200, 'setylim': False,'ymin':0, 'ymax':1, 'grid': True,    'gridaxis': 'both', 'plot_title': plot_title[id],
            'traces':trace[id]
            }   
   plots.append(iplot)

ids = range(len(y_vars_sim))   
subfigs={ids: plots for ids, plots in zip(ids, plots)}
fig,axs=plotExp.plotExp(figs,subfigs,figfiles)




